*********************************************************************
*** Replication file + substantive effects for Gilardi and Wasserfallen (2016): project with Cody and Christopher
***
*** Created: 8-18-17
*** Modified:
***
*********************************************************************


clear
set matsize 1200
cd "C:\Users\williamslaro\Documents\Research\Projects\Spatial Methods\Diffusion\Survey\Replication\Gilardi-Wasserfallen-BJPS-2016-replication -- TLSL"

use "replication_archive/article/Figure_1/steuern.dta", clear
tsset cantonid year

/*********************************************************************/
/************* LOAD IN THE WEIGHTS MATRICES  *************************/
/*********************************************************************/

*** W_N: Neighbors
spatwmat using "replication_archive/article/Table_3/W.dta", name(W_N) s
spatwmat using "W/W_N.dta", name(W_Nfull) s

*** W_C: Commuters
spatwmat using "W/W_C.dta", name(W_Cfull)
 
* Commuters for 1990: for 1990-1997
spatwmat using "replication_archive/weights/commuter_1990_rs.dta", name(W_C_1990)

* Commuters for 2000: for 1998-2007
spatwmat using "replication_archive/weights/commuter_2000_rs.dta", name(W_C_2000)

*** W_r: Not in the same conference
spatwmat using "W/W_not.dta", name(W_rfull)

* Not in the same conference (1990)
spatwmat using "replication_archive/weights/not_same_conf_1990_x10_rs.dta", name(W_r_1990)

* Not in the same conference (2000)
spatwmat using "replication_archive/weights/not_same_conf_2000_x10_rs.dta", name(W_r_2000)

*** W_R: In the same conference
spatwmat using "W/W_R.dta", name(W_Rfull)

* In the same conference (1990)
spatwmat using "replication_archive/weights/same_conf_1990_x10_rs.dta", name(W_R_1990)

* In the same conference (2000)
spatwmat using "replication_archive/weights/same_conf_2000_x10_rs.dta", name(W_R_2000)

/*********************************************************************/
/************* MAIN MODELS OF THE ARTICLE, TABLE 3 *******************/
/*********************************************************************/


/******** Model 1 *********/

xtpcse ks_150 spatlag_n_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1) 

* All years
preserve
	sort year cantonid
	drop if year == 1990
	spatgsa ks_150, weights(W_Nfull) moran
restore
	
* Separate years	
foreach y of numlist 1991(1)2007 {
	preserve
		di _newline(2) "********** YEAR = `y' *************"
		keep if year == `y'
		spatgsa ks_150, weights(W_N) moran
	restore
}

/******** Model 2 *********/

xtpcse ks_150 spatlag_c_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1)

* All years
preserve
	sort year cantonid
	drop if year == 1990
	spatgsa ks_150, weights(W_Cfull) moran
restore
	
* Separate years: 1991-1997
foreach y of numlist 1991(1)1997 {
	preserve
		di _newline(2) "********** YEAR = `y' *************"
		keep if year == `y'
		spatgsa ks_150, weights(W_C_1990) moran
	restore
}

* 1998-2007
foreach y of numlist 1998(1)2007 {
	preserve
		di _newline(2) "********** YEAR = `y' *************"
		keep if year == `y'
		spatgsa ks_150, weights(W_C_2000) moran
	restore
}


/******** Model 3 *********/

xtpcse ks_150 sl_not_same_conf_x10_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1)

* All years
preserve
	sort year cantonid
	drop if year == 1990
	spatgsa ks_150, weights(W_rfull) moran
restore
	
* Separate years: 1991-1997
foreach y of numlist 1991(1)1997 {
	preserve
		di _newline(2) "********** YEAR = `y' *************"
		keep if year == `y'
		spatgsa ks_150, weights(W_r_1990) moran
	restore
}

* 1998-2007
foreach y of numlist 1998(1)2007 {
	preserve
		di _newline(2) "********** YEAR = `y' *************"
		keep if year == `y'
		spatgsa ks_150, weights(W_r_2000) moran
	restore
}

/******** Model 4 *********/

xtpcse ks_150 sl_same_conf_x10_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1)

* All years
preserve
	sort year cantonid
	drop if year == 1990
	spatgsa ks_150, weights(W_Rfull) moran
restore
	
* Separate years: 1991-1997
foreach y of numlist 1991(1)1997 {
	preserve
		di _newline(2) "********** YEAR = `y' *************"
		keep if year == `y'
		spatgsa ks_150, weights(W_R_1990) moran
	restore
}

* 1998-2007
foreach y of numlist 1998(1)2007 {
	preserve
		di _newline(2) "********** YEAR = `y' *************"
		keep if year == `y'
		spatgsa ks_150, weights(W_R_2000) moran
	restore
}

/******** Model 5 *********/

xtpcse ks_150 sl_not_same_conf_x10_150 sl_same_conf_x10_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1)

* All years
preserve
	sort year cantonid
	drop if year == 1990
	spatgsa ks_150, weights(W_rfull) moran
	spatgsa ks_150, weights(W_Rfull) moran
restore
	
* Separate years: 1991-1997
foreach y of numlist 1991(1)1997 {
	preserve
		di _newline(2) "********** YEAR = `y' *************"
		keep if year == `y'
		
		*** Not in same conference
		spatgsa ks_150, weights(W_r_1990) moran

		*** In same conference
		spatgsa ks_150, weights(W_R_1990) moran		
	restore
}

* 1998-2007
foreach y of numlist 1998(1)2007 {
	preserve
		di _newline(2) "********** YEAR = `y' *************"
		keep if year == `y'
		
		*** Not in same conference
		spatgsa ks_150, weights(W_r_2000) moran
		
		*** In same conference
		spatgsa ks_150, weights(W_R_2000) moran
	restore
}


/************************************************************************************/
/*********** ROBUSTNESS CHECKS, ONLINE SUPPLEMENTARY MATERIAL, TABLE A2 *************/
/************************************************************************************/


/********* With Regional Fixed Effects (1, 2, 3) ***********/

xtpcse ks_150 sl_not_same_conf_x10_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj /*
*/ reg_fe_cent reg_fe_east reg_fe_west reg_fe_nowest _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1)


xtpcse ks_150 sl_same_conf_x10_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj /*
*/ reg_fe_cent reg_fe_east reg_fe_west reg_fe_nowest _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1)


xtpcse ks_150 sl_not_same_conf_x10_150 sl_same_conf_x10_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj /*
*/ reg_fe_cent reg_fe_east reg_fe_west reg_fe_nowest _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1)



/********* Only Canton Fixed Effects (4, 5, 6) ************/

xtpcse ks_150 sl_not_same_conf_x10_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_*, c(psar1)

xtpcse ks_150 sl_same_conf_x10_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_*, c(psar1)

xtpcse ks_150 sl_not_same_conf_x10_150 sl_same_conf_x10_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_*, c(psar1)



/********* Without Year and Unit Fixed Effects (7, 8, 9) **************/

xtpcse ks_150 sl_not_same_conf_x10_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj, c(psar1)

xtpcse ks_150 sl_same_conf_x10_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj, c(psar1)

xtpcse ks_150 sl_not_same_conf_x10_150 sl_same_conf_x10_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj, c(psar1)



/********** No Control For Serial Correlation (10, 11, 12) *************/

xtpcse ks_150 sl_not_same_conf_x10_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007

xtpcse ks_150 sl_same_conf_x10_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007

xtpcse ks_150 sl_not_same_conf_x10_150 sl_same_conf_x10_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007



/********* With Lagged Dependent Variable (13, 14, 15) ************/

xtpcse ks_150 l.ks_150 sl_not_same_conf_x10_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007

xtpcse ks_150 l.ks_150 sl_same_conf_x10_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007

xtpcse ks_150 l.ks_150 sl_not_same_conf_x10_150 sl_same_conf_x10_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007




/********* Without Northwestern Conference (16, 17, 18) ************/

xtpcse ks_150 sl_nsc_x10_ohne_nws_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1)


xtpcse ks_150 sl_sc_x10_ohne_nws_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1)


xtpcse ks_150 sl_nsc_x10_ohne_nws_150 sl_sc_x10_ohne_nws_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1)




/********* With Travel Data (weights x10) (19, 20, 21) ************/

xtpcse ks_150 sl_nsc_travel_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1)

xtpcse ks_150 sl_sc_travel_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1)

xtpcse ks_150 sl_nsc_travel_150 sl_sc_travel_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1)










