/******************************************************************************************************
/********************* ESTIMATE COEFFICIENTS AND STANDARD ERRORS OF MAIN MODELS  *********************
/********************* FOR ALL INCOME GROUPS AS SHOWN IN FIGURE 2 OF THE ARTICLE ********************
/*****************************************************************************************************/ 
 
// THE FOLLOWING CODE SHOWS HOW THE MODELS ARE ESTIMATED AND HOW THE ESTIMATES ARE STORED IN CSV-FILES. 
// FIGURE 2 OF THE ARTICLE IS MADE IN R (SEE OTHER CODE) WITH THE CSV-FILES CREATED WITH THE FOLLOWING CODE. 


/******************************************************************************
************** COMPETITORS x10 IF IN SAME CONFERENCE **************************
******************************************************************************/

clear
cd "/Users/.../replication_archive/article/Figure_2"
set more off

/* create an empty dataset with the comp_SC_x10.dta */

clear 
save comp_SC_x10.dta, replace

clear
use steuern.dta
tsset cantonid year 


/* Model 4 in Table 3 */

xtpcse ks_150 sl_same_conf_x10_150 schulden_capita_in10000 defizit_capita_in10000 arbl  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994 y1995 /*
*/ y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1) 

matrix list e(b)


/* Estimate models for all income groups */

qui foreach x in 20 30 40 50 60 70 80 90 100 150 200 300 400 500 1000 {

use steuern.dta

  xtpcse ks_`x' sl_same_conf_x10_`x' schulden_capita_in10000 defizit_capita_in10000 arbl  /*
*/ ausg_capita_in10000  ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994 y1995  /*
*/ y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1)

matrix coef_n_reg_`x' = e(b)'
mat coef_sl_n_reg_`x' = coef_n_reg_`x'[1,1]

matrix ster_n_reg_`x' = e(V)' 
mat ster_sl_n_reg_`x' = ster_n_reg_`x'[1,1]

	use comp_SC_x10.dta
	svmat coef_sl_n_reg_`x'	
	svmat ster_sl_n_reg_`x'
	
	save comp_SC_x10.dta, replace
   
       noi display "." _c                                                  
    } 


/* Make a clean dataset with coefficients and SEs */

clear
use comp_SC_x10.dta

rename var1 ks  
set obs 1
replace ks = 20 in 1 
set obs 2
replace ks = 30 in 2
set obs 3
replace ks = 40 in 3
set obs 4 
replace ks = 50 in 4
set obs 5 
replace ks = 60 in 5
set obs 6 
replace ks = 70 in 6
set obs 7 
replace ks = 80 in 7
set obs 8 
replace ks = 90 in 8
set obs 9 
replace ks = 100 in 9
set obs 10 
replace ks = 150 in 10
set obs 11
replace ks = 200 in 11
set obs 12
replace ks = 300 in 12
set obs 13
replace ks = 400 in 13
set obs 14
replace ks = 500 in 14
set obs 15
replace ks = 1000 in 15

g coef_n_reg=.
sum coef_sl_n_reg_201             
local c=r(max)
replace coef_n_reg in 1 = r(max)  
sum coef_sl_n_reg_301            
local c=r(max)
replace coef_n_reg in 2 = r(max)  
sum coef_sl_n_reg_401            
local c=r(max)
replace coef_n_reg in 3 = r(max)  
sum coef_sl_n_reg_501            
local c=r(max)
replace coef_n_reg in 4 = r(max)  
sum coef_sl_n_reg_601            
local c=r(max)
replace coef_n_reg in 5 = r(max)  
sum coef_sl_n_reg_701            
local c=r(max)
replace coef_n_reg in 6 = r(max)  
sum coef_sl_n_reg_801            
local c=r(max)
replace coef_n_reg in 7 = r(max)  
sum coef_sl_n_reg_901            
local c=r(max)
replace coef_n_reg in 8 = r(max)  
sum coef_sl_n_reg_1001           
local c=r(max)
replace coef_n_reg in 9 = r(max) 
sum coef_sl_n_reg_1501                  
local c=r(max)
replace coef_n_reg in 10 = r(max)  
sum coef_sl_n_reg_2001                
local c=r(max)
replace coef_n_reg in 11 = r(max)  
sum coef_sl_n_reg_3001                 
local c=r(max)
replace coef_n_reg in 12 = r(max)  
sum coef_sl_n_reg_4001                  
local c=r(max)
replace coef_n_reg in 13 = r(max)  
sum coef_sl_n_reg_5001                  
local c=r(max)
replace coef_n_reg in 14 = r(max)  
sum coef_sl_n_reg_10001                  
local c=r(max)
replace coef_n_reg in 15 = r(max)  

g var_n_reg=.
sum ster_sl_n_reg_201             
local c=r(max)
replace var_n_reg in 1 = r(max)  
sum ster_sl_n_reg_301            
local c=r(max)
replace var_n_reg in 2 = r(max)  
sum ster_sl_n_reg_401            
local c=r(max)
replace var_n_reg in 3 = r(max)  
sum ster_sl_n_reg_501            
local c=r(max)
replace var_n_reg in 4 = r(max)  
sum ster_sl_n_reg_601            
local c=r(max)
replace var_n_reg in 5 = r(max)  
sum ster_sl_n_reg_701            
local c=r(max)
replace var_n_reg in 6 = r(max)  
sum ster_sl_n_reg_801            
local c=r(max)
replace var_n_reg in 7 = r(max)  
sum ster_sl_n_reg_901            
local c=r(max)
replace var_n_reg in 8 = r(max)  
sum ster_sl_n_reg_1001           
local c=r(max)
replace var_n_reg in 9 = r(max) 
sum ster_sl_n_reg_1501                  
local c=r(max)
replace var_n_reg in 10 = r(max)  
sum ster_sl_n_reg_2001                
local c=r(max)
replace var_n_reg in 11 = r(max)  
sum ster_sl_n_reg_3001                 
local c=r(max)
replace var_n_reg in 12 = r(max)  
sum ster_sl_n_reg_4001                  
local c=r(max)
replace var_n_reg in 13 = r(max)  
sum ster_sl_n_reg_5001                  
local c=r(max)
replace var_n_reg in 14 = r(max)  
sum ster_sl_n_reg_10001                  
local c=r(max)
replace var_n_reg in 15 = r(max) 


g ster_n_reg = var_n_reg^0.5
save, replace


clear
use comp_SC_x10.dta
outsheet using comp_SC_x10.csv, c replace



/**********************************************************************************
************** COMPETITORS x10 IF NOT IN SAME CONFERENCE **************************
**********************************************************************************/

/* create an empty dataset with the name comp_NSC_x10.dta */

clear 
save comp_NSC_x10.dta, replace

clear
use steuern.dta
tsset cantonid year 

/* Model 3 in Table 3 */

xtpcse ks_150 sl_not_same_conf_x10_150 schulden_capita_in10000 defizit_capita_in10000 arbl  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994 y1995 /*
*/ y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1) 

matrix list e(b)

/* Estimate models for all income groups */

qui foreach x in 20 30 40 50 60 70 80 90 100 150 200 300 400 500 1000 {

   use steuern.dta

  xtpcse ks_`x' sl_not_same_conf_x10_`x' schulden_capita_in10000 defizit_capita_in10000 arbl  /*
*/ ausg_capita_in10000  ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994 y1995  /*
*/ y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1)

matrix coef_n_reg_`x' = e(b)'
mat coef_sl_n_reg_`x' = coef_n_reg_`x'[1,1]

matrix ster_n_reg_`x' = e(V)' 
mat ster_sl_n_reg_`x' = ster_n_reg_`x'[1,1]


	use comp_NSC_x10.dta
	svmat coef_sl_n_reg_`x'	
	svmat ster_sl_n_reg_`x'
	
	save comp_NSC_x10.dta, replace
   
       noi display "." _c                                                  
    } 


/* Make a clean dataset with coefficients and SEs */

clear
use comp_NSC_x10.dta

rename var1 ks  
set obs 1
replace ks = 20 in 1 
set obs 2
replace ks = 30 in 2
set obs 3
replace ks = 40 in 3
set obs 4 
replace ks = 50 in 4
set obs 5 
replace ks = 60 in 5
set obs 6 
replace ks = 70 in 6
set obs 7 
replace ks = 80 in 7
set obs 8 
replace ks = 90 in 8
set obs 9 
replace ks = 100 in 9
set obs 10 
replace ks = 150 in 10
set obs 11
replace ks = 200 in 11
set obs 12
replace ks = 300 in 12
set obs 13
replace ks = 400 in 13
set obs 14
replace ks = 500 in 14
set obs 15
replace ks = 1000 in 15

g coef_n_reg=.
sum coef_sl_n_reg_201             
local c=r(max)
replace coef_n_reg in 1 = r(max)  
sum coef_sl_n_reg_301            
local c=r(max)
replace coef_n_reg in 2 = r(max)  
sum coef_sl_n_reg_401            
local c=r(max)
replace coef_n_reg in 3 = r(max)  
sum coef_sl_n_reg_501            
local c=r(max)
replace coef_n_reg in 4 = r(max)  
sum coef_sl_n_reg_601            
local c=r(max)
replace coef_n_reg in 5 = r(max)  
sum coef_sl_n_reg_701            
local c=r(max)
replace coef_n_reg in 6 = r(max)  
sum coef_sl_n_reg_801            
local c=r(max)
replace coef_n_reg in 7 = r(max)  
sum coef_sl_n_reg_901            
local c=r(max)
replace coef_n_reg in 8 = r(max)  
sum coef_sl_n_reg_1001           
local c=r(max)
replace coef_n_reg in 9 = r(max) 
sum coef_sl_n_reg_1501                  
local c=r(max)
replace coef_n_reg in 10 = r(max)  
sum coef_sl_n_reg_2001                
local c=r(max)
replace coef_n_reg in 11 = r(max)  
sum coef_sl_n_reg_3001                 
local c=r(max)
replace coef_n_reg in 12 = r(max)  
sum coef_sl_n_reg_4001                  
local c=r(max)
replace coef_n_reg in 13 = r(max)  
sum coef_sl_n_reg_5001                  
local c=r(max)
replace coef_n_reg in 14 = r(max)  
sum coef_sl_n_reg_10001                  
local c=r(max)
replace coef_n_reg in 15 = r(max)  

g var_n_reg=.
sum ster_sl_n_reg_201             
local c=r(max)
replace var_n_reg in 1 = r(max)  
sum ster_sl_n_reg_301            
local c=r(max)
replace var_n_reg in 2 = r(max)  
sum ster_sl_n_reg_401            
local c=r(max)
replace var_n_reg in 3 = r(max)  
sum ster_sl_n_reg_501            
local c=r(max)
replace var_n_reg in 4 = r(max)  
sum ster_sl_n_reg_601            
local c=r(max)
replace var_n_reg in 5 = r(max)  
sum ster_sl_n_reg_701            
local c=r(max)
replace var_n_reg in 6 = r(max)  
sum ster_sl_n_reg_801            
local c=r(max)
replace var_n_reg in 7 = r(max)  
sum ster_sl_n_reg_901            
local c=r(max)
replace var_n_reg in 8 = r(max)  
sum ster_sl_n_reg_1001           
local c=r(max)
replace var_n_reg in 9 = r(max) 
sum ster_sl_n_reg_1501                  
local c=r(max)
replace var_n_reg in 10 = r(max)  
sum ster_sl_n_reg_2001                
local c=r(max)
replace var_n_reg in 11 = r(max)  
sum ster_sl_n_reg_3001                 
local c=r(max)
replace var_n_reg in 12 = r(max)  
sum ster_sl_n_reg_4001                  
local c=r(max)
replace var_n_reg in 13 = r(max)  
sum ster_sl_n_reg_5001                  
local c=r(max)
replace var_n_reg in 14 = r(max)  
sum ster_sl_n_reg_10001                  
local c=r(max)
replace var_n_reg in 15 = r(max) 

g ster_n_reg = var_n_reg^0.5

save, replace

clear
use comp_NSC_x10.dta
outsheet using comp_NSC_x10.csv, c replace




/************************************************************************************************
********* COMPETITORS x10 IN SAME CONFRENECE AND NOT IN SAME CONFERENCE IN SAME MODEL ***********
************************************************************************************************/

/* create an empty dataset with the name comp_SC_NSC_x10.dta */

clear 
save comp_SC_NSC_x10.dta, replace


clear
use steuern.dta
tsset cantonid year 

/* Model 5 in Table 3 */

xtpcse ks_150 sl_same_conf_x10_150 sl_not_same_conf_x10_150 schulden_capita_in10000 defizit_capita_in10000 arbl  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994 y1995  /*
*/ y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1) 

ereturn list
matrix list e(V)

/* Estimate models for all income groups */

qui foreach x in 20 30 40 50 60 70 80 90 100 150 200 300 400 500 1000 {

   use steuern.dta

  xtpcse ks_`x' sl_same_conf_x10_`x' sl_not_same_conf_x10_`x' schulden_capita_in10000 defizit_capita_in10000 arbl  /*
*/ ausg_capita_in10000  ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994 y1995  /*
*/ y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1)

matrix coef_n_`x' = e(b)'
mat coef_sl_n_`x' = coef_n_`x'[1,1]
matrix coef_reg_no_n_`x' = e(b)'
mat coef_sl_reg_no_n_`x' = coef_reg_no_n_`x'[2,1]

matrix ster_n_`x' = e(V)' 
mat ster_sl_n_`x' = ster_n_`x'[1,1]
matrix ster_reg_no_n_`x' = e(V)' 
mat ster_sl_reg_no_n_`x' = ster_reg_no_n_`x'[2,2]


	use comp_SC_NSC_x10.dta
	svmat coef_sl_n_`x'
	svmat coef_sl_reg_no_n_`x'
	
	svmat ster_sl_n_`x'
	svmat ster_sl_reg_no_n_`x'
	

	save comp_SC_NSC_x10.dta, replace
   
       noi display "." _c                                                  
    } 



/* Make a clean dataset with coefficients and SEs */

clear
use comp_SC_NSC_x10.dta

rename var1 ks  
set obs 1
replace ks = 20 in 1 
set obs 2
replace ks = 30 in 2
set obs 3
replace ks = 40 in 3
set obs 4 
replace ks = 50 in 4
set obs 5 
replace ks = 60 in 5
set obs 6 
replace ks = 70 in 6
set obs 7 
replace ks = 80 in 7
set obs 8 
replace ks = 90 in 8
set obs 9 
replace ks = 100 in 9
set obs 10 
replace ks = 150 in 10
set obs 11
replace ks = 200 in 11
set obs 12
replace ks = 300 in 12
set obs 13
replace ks = 400 in 13
set obs 14
replace ks = 500 in 14
set obs 15
replace ks = 1000 in 15

g coef_n=.
sum coef_sl_n_201             
local c=r(max)
replace coef_n in 1 = r(max)  
sum coef_sl_n_301            
local c=r(max)
replace coef_n in 2 = r(max)  
sum coef_sl_n_401            
local c=r(max)
replace coef_n in 3 = r(max)  
sum coef_sl_n_501            
local c=r(max)
replace coef_n in 4 = r(max)  
sum coef_sl_n_601            
local c=r(max)
replace coef_n in 5 = r(max)  
sum coef_sl_n_701            
local c=r(max)
replace coef_n in 6 = r(max)  
sum coef_sl_n_801            
local c=r(max)
replace coef_n in 7 = r(max)  
sum coef_sl_n_901            
local c=r(max)
replace coef_n in 8 = r(max)  
sum coef_sl_n_1001           
local c=r(max)
replace coef_n in 9 = r(max) 
sum coef_sl_n_1501                  
local c=r(max)
replace coef_n in 10 = r(max)  
sum coef_sl_n_2001                
local c=r(max)
replace coef_n in 11 = r(max)  
sum coef_sl_n_3001                 
local c=r(max)
replace coef_n in 12 = r(max)  
sum coef_sl_n_4001                  
local c=r(max)
replace coef_n in 13 = r(max)  
sum coef_sl_n_5001                  
local c=r(max)
replace coef_n in 14 = r(max)  
sum coef_sl_n_10001                  
local c=r(max)
replace coef_n in 15 = r(max)  

g coef_reg_no_n=.
sum coef_sl_reg_no_n_201             
local c=r(max)
replace coef_reg_no_n in 1 = r(max)  
sum coef_sl_reg_no_n_301            
local c=r(max)
replace coef_reg_no_n in 2 = r(max)  
sum coef_sl_reg_no_n_401            
local c=r(max)
replace coef_reg_no_n in 3 = r(max)  
sum coef_sl_reg_no_n_501            
local c=r(max)
replace coef_reg_no_n in 4 = r(max)  
sum coef_sl_reg_no_n_601            
local c=r(max)
replace coef_reg_no_n in 5 = r(max)  
sum coef_sl_reg_no_n_701            
local c=r(max)
replace coef_reg_no_n in 6 = r(max)  
sum coef_sl_reg_no_n_801            
local c=r(max)
replace coef_reg_no_n in 7 = r(max)  
sum coef_sl_reg_no_n_901            
local c=r(max)
replace coef_reg_no_n in 8 = r(max)  
sum coef_sl_reg_no_n_1001           
local c=r(max)
replace coef_reg_no_n in 9 = r(max) 
sum coef_sl_reg_no_n_1501                  
local c=r(max)
replace coef_reg_no_n in 10 = r(max)  
sum coef_sl_reg_no_n_2001                
local c=r(max)
replace coef_reg_no_n in 11 = r(max)  
sum coef_sl_reg_no_n_3001                 
local c=r(max)
replace coef_reg_no_n in 12 = r(max)  
sum coef_sl_reg_no_n_4001                  
local c=r(max)
replace coef_reg_no_n in 13 = r(max)  
sum coef_sl_reg_no_n_5001                  
local c=r(max)
replace coef_reg_no_n in 14 = r(max)  
sum coef_sl_reg_no_n_10001                  
local c=r(max)
replace coef_reg_no_n in 15 = r(max)  

g var_n=.
sum ster_sl_n_201             
local c=r(max)
replace var_n in 1 = r(max)  
sum ster_sl_n_301            
local c=r(max)
replace var_n in 2 = r(max)  
sum ster_sl_n_401            
local c=r(max)
replace var_n in 3 = r(max)  
sum ster_sl_n_501            
local c=r(max)
replace var_n in 4 = r(max)  
sum ster_sl_n_601            
local c=r(max)
replace var_n in 5 = r(max)  
sum ster_sl_n_701            
local c=r(max)
replace var_n in 6 = r(max)  
sum ster_sl_n_801            
local c=r(max)
replace var_n in 7 = r(max)  
sum ster_sl_n_901            
local c=r(max)
replace var_n in 8 = r(max)  
sum ster_sl_n_1001           
local c=r(max)
replace var_n in 9 = r(max) 
sum ster_sl_n_1501                  
local c=r(max)
replace var_n in 10 = r(max)  
sum ster_sl_n_2001                
local c=r(max)
replace var_n in 11 = r(max)  
sum ster_sl_n_3001                 
local c=r(max)
replace var_n in 12 = r(max)  
sum ster_sl_n_4001                  
local c=r(max)
replace var_n in 13 = r(max)  
sum ster_sl_n_5001                  
local c=r(max)
replace var_n in 14 = r(max)  
sum ster_sl_n_10001                  
local c=r(max)
replace var_n in 15 = r(max) 

g var_reg_no_n=.
sum ster_sl_reg_no_n_201             
local c=r(max)
replace var_reg_no_n in 1 = r(max)  
sum ster_sl_reg_no_n_301            
local c=r(max)
replace var_reg_no_n in 2 = r(max)  
sum ster_sl_reg_no_n_401            
local c=r(max)
replace var_reg_no_n in 3 = r(max)  
sum ster_sl_reg_no_n_501            
local c=r(max)
replace var_reg_no_n in 4 = r(max)  
sum ster_sl_reg_no_n_601            
local c=r(max)
replace var_reg_no_n in 5 = r(max)  
sum ster_sl_reg_no_n_701            
local c=r(max)
replace var_reg_no_n in 6 = r(max)  
sum ster_sl_reg_no_n_801            
local c=r(max)
replace var_reg_no_n in 7 = r(max)  
sum ster_sl_reg_no_n_901            
local c=r(max)
replace var_reg_no_n in 8 = r(max)  
sum ster_sl_reg_no_n_1001           
local c=r(max)
replace var_reg_no_n in 9 = r(max) 
sum ster_sl_reg_no_n_1501                  
local c=r(max)
replace var_reg_no_n in 10 = r(max)  
sum ster_sl_reg_no_n_2001                
local c=r(max)
replace var_reg_no_n in 11 = r(max)  
sum ster_sl_reg_no_n_3001                 
local c=r(max)
replace var_reg_no_n in 12 = r(max)  
sum ster_sl_reg_no_n_4001                  
local c=r(max)
replace var_reg_no_n in 13 = r(max)  
sum ster_sl_reg_no_n_5001                  
local c=r(max)
replace var_reg_no_n in 14 = r(max)  
sum ster_sl_reg_no_n_10001                  
local c=r(max)
replace var_reg_no_n in 15 = r(max) 


g ster_n = var_n^0.5
g ster_reg_no_n = var_reg_no_n^0.5

save, replace



clear
use comp_SC_NSC_x10.dta
outsheet using comp_SC_NSC_x10.csv, c replace


/************************************************************************************************/
