###########################################################################################
########### S-MLE MODELS (22-27) OF TABLE A2 in THE SUPPLEMENTARY MATERIAL ################
###########################################################################################

setwd('/Users/.../replication_archive/supplementary_material/Table_A2/S-MLE')

library(plm)
library(nlme)
library(MASS)
library(bdsmatrix)
library(splm)

tax.data <- read.csv("steuern_SMLE.csv")


###### Make Connectivity Matrices #########

cm.notsame <- read.csv("not_same_conf_x10_stand.csv")
cm.matrix.notsame <- as.matrix(cm.notsame)
cm.aslist.notsame <- mat2listw(cm.matrix.notsame, style="M")

cm.same <- read.csv("same_conf_x10_stand.csv")
cm.matrix.same <- as.matrix(cm.same)
cm.aslist.same <- mat2listw(cm.matrix.same, style="M")


######## Spatial MLE, Year and unit FE (Models 22 and 23)

model <- ks_150 ~ defizit_capita_in10000 + arbl_prozent + schulden_capita_in10000 + ausg_capita_in10000 + ktant_capita_in10000 + pop_ds_log + svp_ej + fdp_ej + cvp_ej + left_ej + fimi_svp_aj + fimi_fdp_aj + fimi_cvp_aj + fimi_left_aj + as.factor(year) 

fe.spmle.notsame <- spml(model, data = tax.data, listw = cm.aslist.notsame, model="within", effect="individual", lag="T", spatial.error="none")
summary(fe.spmle.notsame)

fe.spmle.same <- spml(model, data = tax.data, listw = cm.aslist.same, model="within", effect="individual",  lag="T", spatial.error="none")
summary(fe.spmle.same)



####### Create dataset with LDV ##########

tax.data.tscs <- pdata.frame(tax.data, c("cantonid","year"))

ldv.ks150 <- lag(tax.data.tscs$ks_150,1)
head(ldv.ks150)
new.dataset <- cbind(tax.data,ldv.ks150)
new.dataset2 <- subset(new.dataset, year!=1990)


####### LDV and unit FE (Models 24 and 25)

model <- ks_150 ~ ldv.ks150 + defizit_capita_in10000 + arbl_prozent + schulden_capita_in10000 + ausg_capita_in10000 + ktant_capita_in10000 + pop_ds_log + svp_ej + fdp_ej + cvp_ej + left_ej + fimi_svp_aj + fimi_fdp_aj + fimi_cvp_aj + fimi_left_aj 

fe.spmle.notsame <- spml(model, data = new.dataset2, listw = cm.aslist.notsame, model="within", effect="individual", lag="T", spatial.error="none")
summary(fe.spmle.notsame)

fe.spmle.same <- spml(model, data = new.dataset2, listw = cm.aslist.same, model="within", effect="individual",  lag="T", spatial.error="none")
summary(fe.spmle.same)


########## LDV, unit FE and year FE (Models 26 and 27) 
 
model <- ks_150 ~ ldv.ks150 + defizit_capita_in10000 + arbl_prozent + schulden_capita_in10000 + ausg_capita_in10000 + ktant_capita_in10000 + pop_ds_log + svp_ej + fdp_ej + cvp_ej + left_ej + fimi_svp_aj + fimi_fdp_aj + fimi_cvp_aj + fimi_left_aj + as.factor(year) 

fe.spmle.notsame <- spml(model, data = new.dataset2, listw = cm.aslist.notsame, model="within", effect="individual", lag="T", spatial.error="none")
summary(fe.spmle.notsame)

fe.spmle.same <- spml(model, data = new.dataset2, listw = cm.aslist.same, model="within", effect="individual",  lag="T", spatial.error="none")
summary(fe.spmle.same)

