/*****************************************************************************************************/
/*****************************************************************************************************/
/*********** Pendler, Gewichtung 10X wenn Kantone in gleicher Reg Konferenz sind *********************/
/*****************************************************************************************************/
/*****************************************************************************************************/

clear
cd "/Users/fabiowasserfallen/Desktop/"
set more off


/***************************************************/
/* Create vectors of the LDV for all income groups */
/***************************************************/

use steuern.dta

local ymin=1990                                                                                
local ymax=2007                                

qui foreach x in 20 30 40 50 60 70 80 90 100 150 200 300 400 500 1000 {

quietly forval y=`ymin'/`ymax' {                                                                   

    local yy=`y'+1                                  
    mkmat ks_`x' if year==`y', matrix(Y_ks`x'_`yy')    
   
   	noisily display "." _c                     
 
 }                                                  
noisily display "`x' " _c

}

matrix list Y_ks20_1998								
sum ks_20 if year==1997 & cantonid==2  	
matrix list Y_ks100_2007
sum ks_100 if year==2006 & cantonid==4



/********************************************************************************************
************** 1990 ************ 1990 ********** 1990 *********** 1990 **********************
*********************************************************************************************/

/*******************************/
/* Create connectivity matrix */
/******************************/

/* Standardize data for the standardized connectivity matrix */

clear
copy same_conf_1990_x10.csv same_conf_1990_x10_stand.csv, replace            

clear
insheet using same_conf_1990_x10_stand.csv                                                  
                       
egen rsum=rowtotal(v1-v26)              

quietly forval j=1/26 {                
    replace v`j'=v`j'/rsum              
}                                      

cap drop rsum       

outsheet using same_conf_1990_x10_stand.csv, c replace

clear 
insheet using same_conf_1990_x10_stand.csv  
mkmat v1-v26, mat(ma_CC_1990_st)                        
matrix list ma_CC_1990_st


/***************************************************/
/* Generate spatlag variables for all income goups */
/***************************************************/

clear 
use steuern.dta

qui foreach x in 20 30 40 50 60 70 80 90 100 150 200 300 400 500 1000 {
cap g sl_same_conf_x10_1990_`x'=.                           
replace sl_same_conf_x10_1990_`x'=.                      
} 

save, replace 

/*************************************************************************************/
/* Insheet spatlag values in the new created variables with a fantastic triple loop */
/************************************************************************************/


local ymin=1991                      
local ymax=2007                          
                     
qui foreach x in 20 30 40 50 60 70 80 90 100 150 200 300 400 500 1000 {

quietly forval y=`ymin'/`ymax' {            
    matrix ma_sl_CC_1990_`y'_`x'=ma_CC_1990_st*Y_ks`x'_`y'                
    
    forval i=1/26 {                                                        
        replace sl_same_conf_x10_1990_`x'=ma_sl_CC_1990_`y'_`x'[`i',1] if cantonid==`i' & year==`y'                                                                                  
                                                
    } 
 }
   noi display "`x' "
 }

browse canton year sl_same_conf_x10_1990_40 sl_same_conf_x10_1990_300

save, replace


/*****************************************************************************************************/
/******** Pendler, Gewichtung 10x wenn Kantone NICHT in gleicher Reg Konferenz sind *************/
/*****************************************************************************************************/


/*******************************/
/* Create connectivity matrix */
/******************************/

/* Standardize data for the standardized connectivity matrix */

copy not_same_conf_1990_x10.csv not_same_conf_1990_x10_stand.csv, replace            

clear
insheet using not_same_conf_1990_x10_stand.csv                                                  
                       
egen rsum=rowtotal(v1-v26)              

quietly forval j=1/26 {                
    replace v`j'=v`j'/rsum              
}                                      

cap drop rsum       

outsheet using not_same_conf_1990_x10_stand.csv, c replace

clear 
insheet using not_same_conf_1990_x10_stand.csv  
mkmat v1-v26, mat(ma_CNC_1990_st)                        
matrix list ma_CNC_1990_st


/***************************************************/
/* Generate spatlag variables for all income goups */
/***************************************************/

clear 
use steuern.dta

qui foreach x in 20 30 40 50 60 70 80 90 100 150 200 300 400 500 1000 {
cap g sl_not_same_conf_x10_1990_`x'=.                           
replace sl_not_same_conf_x10_1990_`x'=.                      
} 

save, replace 

/*************************************************************************************/
/* Insheet spatlag values in the new created variables with a fantastic triple loop */
/************************************************************************************/


local ymin=1991                      
local ymax=2007                          
                     
qui foreach x in 20 30 40 50 60 70 80 90 100 150 200 300 400 500 1000 {

quietly forval y=`ymin'/`ymax' {            
    matrix ma_sl_CNC_1990_`y'_`x'=ma_CNC_1990_st*Y_ks`x'_`y'                
    
    forval i=1/26 {                                                        
        replace sl_not_same_conf_x10_1990_`x'=ma_sl_CNC_1990_`y'_`x'[`i',1] if cantonid==`i' & year==`y'                                                                                  
                                                
    } 
 }
   noi display "`x' "
 }

browse canton year sl_not_same_conf_x10_1990_40 sl_not_same_conf_x10_1990_300

save, replace




/****************************************************************************************************
********************** 2000 ************ 2000 ********** 2000 *********** 2000 **********************
****************************************************************************************************/

/****************************************************************************************************/
/*************** Pendler, Gewichtung 10X wenn Kantone in gleicher Reg Konferenz  ********************/
/****************************************************************************************************/

/*******************************/
/* Create connectivity matrix */
/******************************/

/* Standardize data for the standardized connectivity matrix */

clear
copy same_conf_2000_x10.csv same_conf_2000_x10_stand.csv, replace            

clear
insheet using same_conf_2000_x10_stand.csv                                                  
                       
egen rsum=rowtotal(v1-v26)              

quietly forval j=1/26 {                
    replace v`j'=v`j'/rsum              
}                                      

cap drop rsum       

outsheet using same_conf_2000_x10_stand.csv, c replace

clear 
insheet using same_conf_2000_x10_stand.csv  
mkmat v1-v26, mat(ma_CC_2000_st)                        
matrix list ma_CC_2000_st


/***************************************************/
/* Generate spatlag variables for all income goups */
/***************************************************/

clear 
use steuern.dta

qui foreach x in 20 30 40 50 60 70 80 90 100 150 200 300 400 500 1000 {
cap g sl_same_conf_x10_2000_`x'=.                           
replace sl_same_conf_x10_2000_`x'=.                      
} 

save, replace 

/*************************************************************************************/
/* Insheet spatlag values in the new created variables with a fantastic triple loop */
/************************************************************************************/


local ymin=1991                      
local ymax=2007                          
                     
qui foreach x in 20 30 40 50 60 70 80 90 100 150 200 300 400 500 1000 {

quietly forval y=`ymin'/`ymax' {            
    matrix ma_sl_CC_2000_`y'_`x'=ma_CC_2000_st*Y_ks`x'_`y'                
    
    forval i=1/26 {                                                        
        replace sl_same_conf_x10_2000_`x'=ma_sl_CC_2000_`y'_`x'[`i',1] if cantonid==`i' & year==`y'                                                                                  
                                                
    } 
 }
   noi display "`x' "
 }

browse canton year sl_same_conf_x10_2000_40 sl_same_conf_x10_2000_300

save, replace



/*****************************************************************************************************/
/************ Pendler, Gewichtung 10x wenn Kantone NICHT in gleicher Reg Konferenz  ******************/
/*****************************************************************************************************/

/*******************************/
/* Create connectivity matrix */
/******************************/

/* Standardize data for the standardized connectivity matrix */

clear 
copy not_same_conf_2000_x10.csv not_same_conf_2000_x10_stand.csv, replace            

clear
insheet using not_same_conf_2000_x10_stand.csv                                                  
                       
egen rsum=rowtotal(v1-v26)              

quietly forval j=1/26 {                
    replace v`j'=v`j'/rsum              
}                                      

cap drop rsum       

outsheet using not_same_conf_2000_x10_stand.csv, c replace

clear 
insheet using not_same_conf_2000_x10_stand.csv  
mkmat v1-v26, mat(ma_CNC_2000_st)                        
matrix list ma_CNC_2000_st


/***************************************************/
/* Generate spatlag variables for all income goups */
/***************************************************/

clear 
use steuern.dta

qui foreach x in 20 30 40 50 60 70 80 90 100 150 200 300 400 500 1000 {
cap g sl_not_same_conf_x10_2000_`x'=.                           
replace sl_not_same_conf_x10_2000_`x'=.                      
} 

save, replace 

/*************************************************************************************/
/* Insheet spatlag values in the new created variables with a fantastic triple loop */
/************************************************************************************/


local ymin=1991                      
local ymax=2007                          
                     
qui foreach x in 20 30 40 50 60 70 80 90 100 150 200 300 400 500 1000 {

quietly forval y=`ymin'/`ymax' {            
    matrix ma_sl_CNC_2000_`y'_`x'=ma_CNC_2000_st*Y_ks`x'_`y'                
    
    forval i=1/26 {                                                        
        replace sl_not_same_conf_x10_2000_`x'=ma_sl_CNC_2000_`y'_`x'[`i',1] if cantonid==`i' & year==`y'                                                                                  
                                                
    } 
 }
   noi display "`x' "
 }

browse canton year sl_not_same_conf_x10_2000_40 sl_not_same_conf_x10_2000_300

save, replace




/*****************************************************************************************************/
/*********** C spatlags von 1990 und 2000 zusammenbringen in einen spatlag ***************************/
/*****************************************************************************************************/


qui foreach x in 20 30 40 50 60 70 80 90 100 150 200 300 400 500 1000 {

g sl_same_conf_x10_`x'=.
replace sl_same_conf_x10_`x' = sl_same_conf_x10_1990_`x'                                                                  
replace sl_same_conf_x10_`x' = sl_same_conf_x10_2000_`x' if year>1998

     noi display "." _c                                                      
    } 

browse canton year sl_same_conf_x10_1990_40 sl_same_conf_x10_2000_40 sl_same_conf_x10_40 


qui foreach x in 20 30 40 50 60 70 80 90 100 150 200 300 400 500 1000 {

drop sl_same_conf_x10_1990_`x'
drop sl_same_conf_x10_2000_`x'

     noi display "." _c                                                      
    } 

save, replace
								

/*****************************************************************************************************/


qui foreach x in 20 30 40 50 60 70 80 90 100 150 200 300 400 500 1000 {

g sl_not_same_conf_x10_`x'=.
replace sl_not_same_conf_x10_`x' = sl_not_same_conf_x10_1990_`x'                                                                  
replace sl_not_same_conf_x10_`x' = sl_not_same_conf_x10_2000_`x' if year>1998

     noi display "." _c                                                      
    } 

browse canton year sl_not_same_conf_x10_1990_40 sl_not_same_conf_x10_2000_40 sl_not_same_conf_x10_40 


qui foreach x in 20 30 40 50 60 70 80 90 100 150 200 300 400 500 1000 {

drop sl_not_same_conf_x10_1990_`x'
drop sl_not_same_conf_x10_2000_`x'

     noi display "." _c                                                      
    } 

save, replace