clear
capture log close
clear mata
clear matrix
set mem 500m
set more off



*	************************************************************************ *
* 	File-Name: TransDemAnalysisRep.do										 *
*	Date:  09/13/10															 *
*	Author: 	James Hollyer                                                *
*	Purpose:   To assess the association between democracy and transparency  *
*	using the fraction of WDI economic indicators reported as a measure of   *
*	transparency for each country-year.										 *
*	Data Input: continuous_transparency_measure_2010.dta, 					 *
*	CheibubGhandiVreeland.dta			    								 *
*	OS: Windows XP						 								 	 *
*	************************************************************************ *

use "C:\Users\williamslaro\Documents\Research\Projects\Spatial Methods\Diffusion\Survey\Replication\Hollyer, Rosendorff and Vreeland 2011\HRVanalysisJOP.dta", clear

gen fraction_reported_tm1 = L.fraction_reported

*** Generate the TLSL based on all states
tempvar numobs fraction_reported_tm1 totent
bys year: egen `numobs' = count(wdinum)
bys year: egen `totent' = total(fraction_reported_tm1)
gen tlsl = (`totent' - fraction_reported_tm1) / (`numobs' - 1)

*** Generate the TLSL based on regions
tempvar numobs_r totent_r
bys year aclp_region: egen `numobs_r' = count(wdinum)
bys year aclp_region: egen `totent_r' = total(fraction_reported_tm1)
gen tlsl_region = (`totent_r' - fraction_reported_tm1) / (`numobs_r' - 1)
recode tlsl_region (0=.)

*** Full model (Model 6 on Table 2)
xtreg fraction_reported democracy rgdpch under_imf time time2 time3, fe robust

* Without GDP per capita
xtreg fraction_reported tlsl tlsl_region democracy under_imf time time2 time3, fe robust

* Without democracy
reg fraction_reported fraction_reported_tm1 tlsl_region rgdpch democracy under_imf time time2 time3 i.aclp_region, robust

cap log close
log using "C:\Users\williamslaro\Documents\Research\Projects\Spatial Methods\Diffusion\Survey\Replication\Hollyer, Rosendorff and Vreeland 2011\HRV Results.smcl", replace 

*** Polity2 measure of democracy

* Replication of Model 6 (Table 3, page 1201)
xtreg fraction_reported polity2 rgdpch under_imf time time2 time3, fe robust

* Replication + TLSL
xtreg fraction_reported tlsl polity2 rgdpch under_imf time time2 time3, fe robust

* Replication + TLSL - cubic polynomials
xtreg fraction_reported tlsl polity2 rgdpch under_imf, fe robust

* Replication + TLSL - wealth
xtreg fraction_reported tlsl polity2 under_imf time time2 time3, fe robust

log close

*** Democracy
xtreg fraction_reported democracy rgdpch under_imf time time2 time3, fe robust
xtreg fraction_reported tlsl democracy rgdpch under_imf time time2 time3, fe robust
xtreg fraction_reported tlsl democracy under_imf time time2 time3, fe robust
xtreg fraction_reported tlsl democracy rgdpch under_imf, fe robust



*** Replication
*ACLP measures of democracy (Table 2).

reg fraction_reported democracy, cluster(wdicode) robust
estimates store ACLPbivariate, title(Fraction Reported)

reg fraction_reported democracy time time2 time3, cluster(wdicode) robust 
estimates store ACLPbivariate2, title(Fraction Reported)

reg fraction_reported democracy rgdpch time time2 time3, 
cluster(wdicode) robust
estimates store ACLPmultivariate1, title(Fraction Reporting)

reg fraction_reported democracy rgdpch under_imf time time2 time3, 
cluster(wdicode) robust
estimates store ACLPmultivariate2, title(Fraction Reporting)

xtreg fraction_reported democracy rgdpch under_imf, fe robust
estimates store ACLPmultivariate3, title(Fraction Reported)


xtreg fraction_reported democracy rgdpch under_imf time time2 time3, fe robust
estimates store ACLPmultivariate4, title(Fraction Reported)

*Polity measures of democracy (Table 3).

reg fraction_reported polity2, cluster(wdicode) robust
estimates store Politybivariate, title(Fraction Reported)

reg fraction_reported polity2 time time2 time3, cluster(wdicode) robust 
estimates store Politybivariate2, title(Fraction Reported)

reg fraction_reported polity2 rgdpch time time2 time3, 
cluster(wdicode) robust
estimates store Politymultivariate1, title(Fraction Reported)

reg fraction_reported polity2 rgdpch under_imf time time2 time3, 
cluster(wdicode) robust
estimates store Politymultivariate2, title(Fraction Reported)

xtreg fraction_reported polity2 rgdpch under_imf, fe robust
estimates store Politymultivariate3, title(Fraction Reported)

xtreg fraction_reported polity2 rgdpch under_imf time time2 time3, fe robust
estimates store Politymultivariate4, title(Fraction Reported)

*The following will output tables 2 and 3, repsectively.
*(Commented out.)

*estout ACLPbivariate ACLPbivariate2 ACLPmultivariate1 ACLPmultivariate2 
ACLPmultivariate3 ACLPmultivariate4 using "c:\documents and settings\james\desktop\my dropbox\democracy and transparency\frac_reported_ACLP.tex",
cells(b(star fmt(3)) ci(par fmt(3))) stats(rmse) style(tex) replace

*estout Politybivariate Politybivariate2 Politymultivariate1 Politymultivariate2 
Politymultivariate3 Politymultivariate4 using "c:\documents and settings\james\desktop\my dropbox\democracy and transparency\frac_reported_Polity.tex",
cells(b(star fmt(3)) ci(par fmt(3))) stats(rmse) style(tex) replace

*	************************************************************************ *
*	The following will output a histogram of the fraction reported data.	 *
*	(Figure 1).																 *
*	************************************************************************ *

hist fraction_reported, percent graphregion(fcolor(white)) 
xtitle(Fraction of WDI Measures Reported) ytitle(Percentage of Observations)
scheme(s2mono)

graph export "c:\documents and settings\james\desktop\my dropbox\democracy and transparency\jop\jopacceptedversion\fractionreported_hist.tif",
replace
